/*
 * faces.h
 *
 * definition of the faces used by a2ps
 * Copyright (c) 1988, 89, 90, 91, 92, 93 Miguel Santana
 * Copyright (c) 1995, 96, 97 Akim Demaille, Miguel Santana
 *
 */

/*
 * This file is part of a2ps.
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; see the file COPYING.  If not, write to
 * the Free Software Foundation, 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

/*
 * $Id: faces.h,v 1.21 1997/09/02 15:38:42 demaille Exp $
 */

#ifndef _FACES_H_
#define _FACES_H_

struct a2ps_job;
/*
 * There are some faces some are facilities for a2ps-the-program,
 * they have nothing to do a2ps-the-library.  Hence this sequence
 * to extract only what is relevant for a library user.
 */

/* liba2ps.h:begin */
/* fonts used in language modes */
typedef enum face_t { 
/* liba2ps.h:end */
  No_face = -1,
/* liba2ps.h:begin */
  Plain = 0, 
  Symbol = 1, 
  Keyword = 2, Keyword_strong = 3,
  Comment = 4, Comment_strong = 5,
  String = 6,
  Label = 7, Label_strong = 8,
  Error = 9
/* liba2ps.h:end */
  ,
  /* Specials */
  INVISIBLE = 16,
  TAG1 = 32, TAG2 = 64, TAG3 = 128, TAG4 = 256,
  Index1 = 512, Index2 = 1024, Index3 = 2048, Index4 = 4096,
  /* Encoding instruction */
  ENCODING_TAG = 2048,
  /* Masks */
  FACE_MASK = 15
/* liba2ps.h:begin */
} face_t;
/* liba2ps.h:end */


#define NB_FACES  10 /* From Plain to Label_strong */
#define NB_FACES_NULLS	\
	{ NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL}

face_t string_to_face PARAMS ((const char * string));
const char * face_to_ps PARAMS ((face_t face));
const char * face_to_string PARAMS ((face_t face));
uchar * xface_to_string PARAMS ((face_t face));

void init_face_to_font PARAMS ((struct a2ps_job * job));
void face_to_font_free PARAMS ((char * face_to_font [NB_FACES]));
void check_face_to_font PARAMS ((struct a2ps_job * job));
int face_to_font_is_set PARAMS ((struct a2ps_job * job));
void set_face_font PARAMS ((struct a2ps_job * job,
			    face_t face, const char * font_name));
#endif
